==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-61.js <==
dispMUA.arDispMUAAllocation["a"] =
{
  "allaire coldfusion application server" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "alerts delivery system, marketwatch" : [ "marketwatch.png" ] ,
  "admin pro tools email list manager" : [ "apt_email_list_manager.png" ] ,
  "arclab maillist controller" : [ "maillist_controller.png" , "http://www.arclab.com/products/amlc/" ] ,
  "allegro software rommailer" : [ "allegro.png" , "http://www.allegrosoft.com/rommailer.html" ] ,
  "adobe photoshop services" : [ "photoshop.png" , "http://www.adobe.com/products/photoshop/" ] ,
  "add2it mailresponder pro" : [ "mailresponderpro.png" , "http://www.mailresponderpro.com/" ] ,
  "auto-responder - id.kom" : [ "idkom_de.png" , "http://www.idkom.de/" ] ,
  "activxperts activemail" : [ "activxperts.png" ] ,
  "arena internet mailer" : [ "arena_internet_mailer.png" ] ,
  "akna e-mail marketing" : [ "akna.png" , "http://www.akna.com.br/" ] ,
  "asp component bundle" : [ "aspqmail.png" ] ,
  "arclab email toolbox" : [ "arclab.png" , "http://www.arclab.com/products/amlc/" ] ,
  "apsis newsletter pro" : [ "apsis.png" , "http://www.nyhetsbrev.biz/" ] ,
  "adrom e-mail manager" : [ "adrom_net.png" , "http://www.adrom.net/" ] ,
  "aconon mail software" : [ "aconon.png" ] ,
  "auctionweb - mailer" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" ] ,
  "at&t message center" : [ "att.png" ] ,
  "airmail for windows" : [ "airmail.png" ] ,
  "animexx mailritter" : [ "animexx.png" ] ,
  "amicron mailoffice" : [ "amicron.png" ] ,
  "adiscon simplemail" : [ "simplemail.png" , "http://www.simplemail.adiscon.com/" ] ,
  "apple .mac mailer" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "allegro's promail" : [ "allegro_biz.png" , "http://www.allegro.biz/promail.htm" ] ,
  "agnitas ag/conrad" : [ "conrad.png" , "http://www.conrad.de/" ] ,
  "animation mailer" : [ "animecha.png" , "http://www.animecha.com/" ] ,
  "akio mail center" : [ "akio.png" ] ,
  "americasnet.com" : [ "americasnet_com.png" , "http://www.americasnet.com/" ] ,
  "ambit new media" : [ "ambit.png" ] ,
  "advalvas mailer" : [ "advalvas.png" ] ,
  "axigen webmail" : [ "axigen.png" , "http://www.axigen.com/" ] ,
  "agonet webmail" : [ "agonet.png" , "http://www.agonet.it/" ] ,
  "acro media inc" : [ "acromedia.png" ] ,
  "atlantisworld" : [ "atlantisworld.png" ] ,
  "aster webmail" : [ "aster.png" ] ,
  "aranay mailer" : [ "aranay.png" , "http://www.aranay.com/" ] ,
  "aport webmail" : [ "aport.png" , "http://www.aport.ru/" ] ,
  "alice-webmail" : [ "alice_webmail.png" ] ,
  "atlas mailer" : [ "netscape.png" ] ,
  "agendus mail" : [ "agendus.png" , "http://www.iambic.com/" ] ,
  "afs-kaufmann" : [ "afs-software.png" , "http://www.afs-software.de/" ] ,
  "activitymail" : [ "activitymail.png" , "http://search.cpan.org/dist/activitymail/" ] ,
  "active! mail" : [ "active_mail_jp.png" , "http://activemail.jp/" ] ,
  "ability mail" : [ "ability_mail.png" ] ,
  "auto mailer" : [ "auto_mailer.png" ] ,
  "aspnetemail" : [ "aspnetemail.png" ] ,
  "asp smtpsvg" : [ "aspqmail.png" ] ,
  "apollo mail" : [ "apollo_mail.png" , "http://www.apollomail.com/" ] ,
  "aon webmail" : [ "aon.png" , "http://www.aon.at/" ] ,
  "aim webmail" : [ "aol.png" , "http://www.aol.com/" ] ,
  "active.mail" : [ "active.mail.png" ] ,
  "applixware" : [ "applixware.png" ] ,
  "apple mail" : [ "apple_mail.png" , "http://www.apple.com/de/macosx/features/mail.html" ] ,
  "activemail" : [ "activemail.png" ] ,
  "a1 webmail" : [ "a1webmail.png" , "http://www.a1.net/" ] ,
  "anglemail" : [ "anglemail.png" , "http://www.anglemail.org/" ] ,
  "amos mail" : [ "amos_mail.png" ] ,
  "alphamail" : [ "alphamail.png" , "http://alphamail.sourceforge.net/" ] ,
  "al-mail32" : [ "almail.png" ] ,
  "agregator" : [ "viadeo.png" , "http://www.viadeo.com/" ] ,
  "activefax" : [ "activefax.png" , "http://www.activefax-software.de/" ] ,
  "aspqmail" : [ "aspqmail.png" ] ,
  "aeromail" : [ "aeromail.png" , "http://the.cushman.net/reverb/aeromail/" ] ,
  "accucast" : [ "accucast.png" ] ,
  "azureus" : [ "azureus.png" ] ,
  "azet.sk" : [ "azet_sk.png" , "http://www.azet.sk/" ] ,
  "atmail " : [ "atmail.png" , "http://www.atmail.com/" ] ,
  "aspmail" : [ "aspqmail.png" ] ,
  "asp.net" : [ "asp_net.png" , "http://www.asp.net/" ] ,
  "arcabit" : [ "arcabit.png" , "http://www.arcabit.com/" ] ,
  "amember" : [ "cgi-central_net.png" , "http://www.amember.com/" ] ,
  "ak-mail" : [ "ak_mail.png" ] ,
  "agnitas" : [ "agnitas.png" ] ,
  "aethera" : [ "aethera.png" ] ,
  "adtoone" : [ "adtoone.png" ] ,
  "abvmail" : [ "abvmail.png" ] ,
  "aweber" : [ "aweber.png" ] ,
  "avenum" : [ "avenum.png" , "http://www.avenum.com/" ] ,
  "arclab" : [ "arclab.png" , "http://www.arclab.com/products/amlc/" ] ,
  "alpine" : [ "alpine.png" , "http://www.washington.edu/alpine/" ] ,
  "arcor" : [ "arcor.png" ] ,
  "airt" : [ "airt.png" , "http://sourceforge.net/projects/airt" ] ,
  "aol" : [ "aol.png" , "http://www.aol.com/" ] ,
  "afp" : [ "afp.png" , "http://www.afpnet.org/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-61.js <==
dispMUA.arDispMUAAllocation["a"] =
{
  "allaire coldfusion application server" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "alerts delivery system, marketwatch" : [ "marketwatch.png" ] ,
  "admin pro tools email list manager" : [ "apt_email_list_manager.png" ] ,
  "arclab maillist controller" : [ "maillist_controller.png" , "http://www.arclab.com/products/amlc/" ] ,
  "allegro software rommailer" : [ "allegro.png" , "http://www.allegrosoft.com/rommailer.html" ] ,
  "adobe photoshop services" : [ "photoshop.png" , "http://www.adobe.com/products/photoshop/" ] ,
  "add2it mailresponder pro" : [ "mailresponderpro.png" , "http://www.mailresponderpro.com/" ] ,
  "auto-responder - id.kom" : [ "idkom_de.png" , "http://www.idkom.de/" ] ,
  "activxperts activemail" : [ "activxperts.png" ] ,
  "arena internet mailer" : [ "arena_internet_mailer.png" ] ,
  "akna e-mail marketing" : [ "akna.png" , "http://www.akna.com.br/" ] ,
  "asp component bundle" : [ "aspqmail.png" ] ,
  "arclab email toolbox" : [ "arclab.png" , "http://www.arclab.com/products/amlc/" ] ,
  "apsis newsletter pro" : [ "apsis.png" , "http://www.nyhetsbrev.biz/" ] ,
  "adrom e-mail manager" : [ "adrom_net.png" , "http://www.adrom.net/" ] ,
  "aconon mail software" : [ "aconon.png" ] ,
  "auctionweb - mailer" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" ] ,
  "at&t message center" : [ "att.png" ] ,
  "airmail for windows" : [ "airmail.png" ] ,
  "animexx mailritter" : [ "animexx.png" ] ,
  "amicron mailoffice" : [ "amicron.png" ] ,
  "adiscon simplemail" : [ "simplemail.png" , "http://www.simplemail.adiscon.com/" ] ,
  "apple .mac mailer" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "allegro's promail" : [ "allegro_biz.png" , "http://www.allegro.biz/promail.htm" ] ,
  "agnitas ag/conrad" : [ "conrad.png" , "http://www.conrad.de/" ] ,
  "animation mailer" : [ "animecha.png" , "http://www.animecha.com/" ] ,
  "akio mail center" : [ "akio.png" ] ,
  "americasnet.com" : [ "americasnet_com.png" , "http://www.americasnet.com/" ] ,
  "ambit new media" : [ "ambit.png" ] ,
  "advalvas mailer" : [ "advalvas.png" ] ,
  "axigen webmail" : [ "axigen.png" , "http://www.axigen.com/" ] ,
  "agonet webmail" : [ "agonet.png" , "http://www.agonet.it/" ] ,
  "acro media inc" : [ "acromedia.png" ] ,
  "atlantisworld" : [ "atlantisworld.png" ] ,
  "aster webmail" : [ "aster.png" ] ,
  "aranay mailer" : [ "aranay.png" , "http://www.aranay.com/" ] ,
  "aport webmail" : [ "aport.png" , "http://www.aport.ru/" ] ,
  "alice-webmail" : [ "alice_webmail.png" ] ,
  "atlas mailer" : [ "netscape.png" ] ,
  "agendus mail" : [ "agendus.png" , "http://www.iambic.com/" ] ,
  "afs-kaufmann" : [ "afs-software.png" , "http://www.afs-software.de/" ] ,
  "activitymail" : [ "activitymail.png" , "http://search.cpan.org/dist/activitymail/" ] ,
  "active! mail" : [ "active_mail_jp.png" , "http://activemail.jp/" ] ,
  "ability mail" : [ "ability_mail.png" ] ,
  "auto mailer" : [ "auto_mailer.png" ] ,
  "aspnetemail" : [ "aspnetemail.png" ] ,
  "asp smtpsvg" : [ "aspqmail.png" ] ,
  "apollo mail" : [ "apollo_mail.png" , "http://www.apollomail.com/" ] ,
  "aon webmail" : [ "aon.png" , "http://www.aon.at/" ] ,
  "amtangee(r)" : [ "amtangee.png" , "http://www.amtangee.com/" ] ,
  "aim webmail" : [ "aol.png" , "http://www.aol.com/" ] ,
  "active.mail" : [ "active.mail.png" ] ,
  "applixware" : [ "applixware.png" ] ,
  "apple mail" : [ "apple_mail.png" , "http://www.apple.com/de/macosx/features/mail.html" ] ,
  "activemail" : [ "activemail.png" ] ,
  "a1 webmail" : [ "a1webmail.png" , "http://www.a1.net/" ] ,
  "anglemail" : [ "anglemail.png" , "http://www.anglemail.org/" ] ,
  "amos mail" : [ "amos_mail.png" ] ,
  "alphamail" : [ "alphamail.png" , "http://alphamail.sourceforge.net/" ] ,
  "al-mail32" : [ "almail.png" ] ,
  "agregator" : [ "viadeo.png" , "http://www.viadeo.com/" ] ,
  "activefax" : [ "activefax.png" , "http://www.activefax-software.de/" ] ,
  "aspqmail" : [ "aspqmail.png" ] ,
  "altobase" : [ "altobase.png" , "http://altobase.jp/asp/" ] ,
  "aeromail" : [ "aeromail.png" , "http://the.cushman.net/reverb/aeromail/" ] ,
  "accucast" : [ "accucast.png" ] ,
  "azureus" : [ "azureus.png" ] ,
  "azet.sk" : [ "azet_sk.png" , "http://www.azet.sk/" ] ,
  "atmail " : [ "atmail.png" , "http://www.atmail.com/" ] ,
  "aspmail" : [ "aspqmail.png" ] ,
  "asp.net" : [ "asp_net.png" , "http://www.asp.net/" ] ,
  "arcabit" : [ "arcabit.png" , "http://www.arcabit.com/" ] ,
  "amember" : [ "cgi-central_net.png" , "http://www.amember.com/" ] ,
  "ak-mail" : [ "ak_mail.png" ] ,
  "agnitas" : [ "agnitas.png" ] ,
  "aethera" : [ "aethera.png" ] ,
  "adtoone" : [ "adtoone.png" ] ,
  "abvmail" : [ "abvmail.png" ] ,
  "aweber" : [ "aweber.png" ] ,
  "avenum" : [ "avenum.png" , "http://www.avenum.com/" ] ,
  "arclab" : [ "arclab.png" , "http://www.arclab.com/products/amlc/" ] ,
  "alpine" : [ "alpine.png" , "http://www.washington.edu/alpine/" ] ,
  "arcor" : [ "arcor.png" ] ,
  "airt" : [ "airt.png" , "http://sourceforge.net/projects/airt" ] ,
  "aol" : [ "aol.png" , "http://www.aol.com/" ] ,
  "afp" : [ "afp.png" , "http://www.afpnet.org/" ] ,
}
